# Acknowledgments

`pyads-agile` is based on the upstream `pyads` project created by Stefan Lehmann.

- Upstream project: https://github.com/stlehmann/pyads
- Original author: Stefan Lehmann
- License: MIT

This repository is maintained by Agile Automation Technologies GmbH.

We thank Stefan Lehmann and all upstream contributors for creating and maintaining
the foundation this distribution builds upon.
